@@ -10,14 +10,14 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-from .adaptive_sampling import (
+from .incremental_sampling import (
     EffectiveSampleSizeCriterion,
     RHatDeviationCriterion,
     EffectiveSampleSizeAndRHatCriterion,
     sample_until
 )
 
-from .arviz import convert_pyjags_samples_dict_to_arviz_inference_data
+# from .arviz import from_pyjags
 from .chain_utilities import (
     discard_burn_in_samples,
     extract_final_iteration_from_samples_for_initialization,
